==> iobroker.fullcalendar-0.2.2.tgz: package/admin/words.js <==
var systemDictionary = {
    "Events":           {"en": "Events",        "de": "Ereignisse",             "ru": "События"},
    "Single event":     {"en": "Single event",  "de": "Einzelereignis",         "ru": "Одиночное"},
    "Double event":     {"en": "Double event",  "de": "An/Aus Ereignis",        "ru": "Несколько"},
    "Toggle event":     {"en": "Toggle event",  "de": "Umschaltereignis",       "ru": "Переключение"},
    "Description":      {"en": "Description:",  "de": "Beschreibung:",          "ru": "Описание:"},
    "Event type":       {"en": "Event type:",   "de": "Eventtyp:",              "ru": "Тип события:"},
    "single":           {"en": "single",        "de": "Einzel",                 "ru": "одиночное"},
    "double":           {"en": "double",        "de": "An/Aus",                 "ru": "несколько"},
    "toggle":           {"en": "toggle",        "de": "Umschalt",               "ru": "переключение"},
    "Duration":         {"en": "Duration:",     "de": "Dauer:",                 "ru": "Длительность:"},
    "Object ID":        {"en": "Object ID:",    "de": "Objekt ID:",             "ru": "ID объекта:"},
    "Start value":      {"en": "Start value:",  "de": "Startwert:",             "ru": "Значение:"},
    "End value":        {"en": "End value:",    "de": "Endwert:",               "ru": "Конечное значение:"},
    "Period":           {"en": "Period:",       "de": "Period:",                "ru": "Повтор:"},
    "Color":            {"en": "Color:",        "de": "Farbe:",                 "ru": "Цвет:"},
    "once":             {"en": "once",          "de": "einmalig",               "ru": "один раз"},
    "daily":            {"en": "daily",         "de": "taglich",                "ru": "ежедневно"},
    "monthly":          {"en": "monthly",       "de": "monatlich",              "ru": "ежемесячно"},
    "Instruction":      {
        "en": "Drag and drop the events above to create a new one.<hr>Use ALT by dragging it to copy the events.",
        "de": "Schiebe die Ereignisse oben auf Kalendar um neue Ereignise zu erzeugen.<hr>Halt ALT beim schieben um die Ereignisse zu kopieren.",
        "ru": "Что бы создать новые события, перетащите события сверху на календарь.<hr>Что бы скопировать событие удерживайте ALT при перетаскивании."
    },
    "Active":           {"en": "Active:",       "de": "Aktiviert:",             "ru": "Активно:"},
    "Time":             {"en": "Time:",         "de": "Zeit:",                  "ru": "Время:"},
    "Delete":           {"en": "Delete",        "de": "Löschen",                "ru": "Удалить"},
    "Cancel":           {"en": "Cancel",        "de": "Abbrechen",              "ru": "Отмена"},
    "Save":             {"en": "Save",          "de": "Speichern",              "ru": "Сохранить"},
    "Configure event":  {"en": "Configure event", "de": "Ereignis einstellen",  "ru": "Настроить событие"},
    "No action":        {"en": "No action",     "de": "Keine Aktion",           "ru": "Нет действия"},
    "Set value":        {"en": "Set value:",    "de": "Setze Wert:",            "ru": "Установить значение:"},
    "Set %s":           {"en": "Set %s",        "de": "Setze %s",               "ru": "Установить %s"},
    "Set %s to %s":     {"en": "Set %s to %s",  "de": "Setze %s zu %s",         "ru": "Установить %s в/на %s"},
    "Set to %s":        {"en": "Set to %s",     "de": "Setze zu %s",            "ru": "Установить в/на %s"},

    "sunrise":          {'en': 'sunrise',       "de": 'Sonnenaufgang',          'ru': 'восход солнца'},
    "sunriseEnd":       {'en': 'sunrise end',   "de": 'Sonnenaufgang-Ende',     'ru': 'конец восхода'},
    "goldenHourEnd":    {'en': 'golden hour end',"de": '"Golden hour"-Ende',    'ru': 'конец золотого часа'},
    "solarNoon":        {'en': 'solar noon',    "de": 'Sonnenmittag',           'ru': 'солнечеый полдень'},
    "goldenHour":       {'en': 'golden hour',   "de": '"Golden hour"',          'ru': 'золотой час'},
    "sunsetStart":      {'en': 'sunset start',  "de": 'Sonnenuntergang-Anfang', 'ru': 'начало захода солнца'},
    "sunset":           {'en': 'sunset',        "de": 'Sonnenuntergang',        'ru': 'конец захода солнца'},
    "dusk":             {'en': 'dusk',          "de": 'Abenddämmerung',         'ru': 'сумерки'},
    "nauticalDusk":     {'en': 'nautical dusk', "de": 'Nautische Abenddämmerung', 'ru': 'навигационные сумерки'},
    "night":            {'en': 'night',         "de": 'Nacht',                  'ru': 'ночь'},
    "nightEnd":         {'en': 'night end',     "de": 'Nachtsende',             'ru': 'конец ночи'},
    "nauticalDawn":     {'en': 'nautical dawn', "de": 'Nautische Morgendämmerung','ru': 'навигационный рассвет'},
    "dawn":             {'en': 'dawn',          "de": 'Morgendämmerung',        'ru': 'рассвет'},
    "nadir":            {'en': 'nadir',         "de": 'Nadir',                  'ru': 'надир'},

    "time":             {"en": "time",          "de": "Zeit",                   "ru": "время"},
    "astro":            {"en": "astro",         "de": "astro",                  "ru": "астро"},
    "Offset":           {"en": "Offset in minutes", "de": "Offset in Minuten",   "ru": "Сдвиг в минутах"},
    "scheduled":        {"en": "none",          "de": "nichts",                 "ru": "не показывать"},
    "configured":       {"en": "from Calendar", "de": "nur aus Kalender",             "ru": "только из календаря"},
    "all":              {"en": "all",           "de": "Alle",                   "ru": "все"},
    "Live Events":      {"en": "Live Events",   "de": "Zeige Ereignise",        "ru": "Показать события"},

    "Mo":               {"en": "Mo",            "de": "Mo",                     "ru": "Пн"},
    "Tu":               {"en": "Tu",            "de": "Di",                     "ru": "Вт"},
    "We":               {"en": "We",            "de": "Mi",                     "ru": "Ср"},
    "Th":               {"en": "Th",            "de": "Do",                     "ru": "Чт"},
    "Fr":               {"en": "Fr",            "de": "Fr",                     "ru": "Пт"},
    "Sa":               {"en": "Sa",            "de": "Sa",                     "ru": "Сб"},
    "Su":               {"en": "Su",            "de": "So",                     "ru": "Вс"},

    "Jan":              {"en": "Jan",           "de": "Jan",                    "ru": "Янв"},
    "Feb":              {"en": "Feb",           "de": "Feb",                    "ru": "Фев"},
    "Mar":              {"en": "Mar",           "de": "März",                   "ru": "Март"},
    "Apr":              {"en": "Apr",           "de": "Apr",                    "ru": "Апр"},
    "May":              {"en": "May",           "de": "Mai",                    "ru": "Май"},
    "Jun":              {"en": "Jun",           "de": "Jun",                    "ru": "Июнь"},
    "Jul":              {"en": "Jul",           "de": "Jul",                    "ru": "Июль"},
    "Aug":              {"en": "Aug",           "de": "Aug",                    "ru": "Авг"},
    "Sep":              {"en": "Sep",           "de": "Sept",                   "ru": "Сен"},
    "Oct":              {"en": "Oct",           "de": "Okt",                    "ru": "Окт"},
    "Nov":              {"en": "Nov",           "de": "Nov",                    "ru": "Ноя"},
    "Dec":              {"en": "Dec",           "de": "Dez",                    "ru": "Дек"},
    "notice_single":    {
        "en": "Will be triggered only once for one time event. Please provide the <b>Object ID</b> and <b>value</b>",
        "de": "Wird nur einmal für zeitliches Ereignis ausgelöst. Bitte geben Sie die <b>Objekt ID</b> und <b>Wert</b> an",
        "ru": "Будет срабатывать только один раз для временного события. Укажите <b>ID объекта</b> и <b>значение</b>, которое будет присвоено."
    },
    "notice_double":    {
        "en": "Will be triggered twice for one time event. One time by start and one time after defined duration. Please provide the <b>Object ID</b>, <b>start</b> and <b>end values</b>.",
        "de": "Wird zweimal für einmaliges Ereignis ausgelöst. Einmal beim Start und einmal nach definiertes Intervall. Bitte geben Sie die <b> Objekt ID </b>, <b>Start-</b> und <b>End-werte</b> an.",
        "ru": "Будет срабатывать дважды для одного временного события. Один раз в начале и один раз после установленного интервала. Укажите <b>ID объекта</b>, <b>начальное</b> и <b>конечные значения</b>."
    },
    "notice_toggle":    {
        "en": "Will be triggered twice for one time event. One time by start and one time after defined duration. Please provide the <b>Object ID</b> and <b>start value</b>. End value will be calculated automatically.",
        "de": "Wird zweimal für einmaliges Ereignis ausgelöst. Einmal beim Start und einmal nach definiertes Intervall. Bitte geben Sie die <b>Objekt ID</b> und <b>Startwert</b> an. Endwert wird automatisch berechnet.",
        "ru": "Будет срабатывать дважды для одного временного события. Один раз в начале и один раз после установленного интервала. Укажите <b>ID объекта</b> и <b>начальное значение</b>. Конечное значение будет рассчитываться автоматически."
    }
};

==> iobroker.fullcalendar-1.2.0.tgz: package/admin/words.js <==
var systemDictionary = {
    "Events":           {"en": "Events",        "de": "Ereignisse",             "ru": "События"},
    "Single event":     {"en": "Single event",  "de": "Einzelereignis",         "ru": "Одиночное"},
    "Double event":     {"en": "Double event",  "de": "An/Aus Ereignis",        "ru": "Несколько"},
    "Toggle event":     {"en": "Toggle event",  "de": "Umschaltereignis",       "ru": "Переключение"},
    "Description":      {"en": "Description:",  "de": "Beschreibung:",          "ru": "Описание:"},
    "Event type":       {"en": "Event type:",   "de": "Eventtyp:",              "ru": "Тип события:"},
    "single":           {"en": "single",        "de": "Einzel",                 "ru": "одиночное"},
    "double":           {"en": "double",        "de": "An/Aus",                 "ru": "несколько"},
    "toggle":           {"en": "toggle",        "de": "Umschalt",               "ru": "переключение"},
    "Duration":         {"en": "Duration:",     "de": "Dauer:",                 "ru": "Длительность:"},
    "Object ID":        {"en": "Object ID:",    "de": "Objekt ID:",             "ru": "ID объекта:"},
    "Start value":      {"en": "Start value:",  "de": "Startwert:",             "ru": "Значение:"},
    "End value":        {"en": "End value:",    "de": "Endwert:",               "ru": "Конечное значение:"},
    "First value":      {"en": "First value:",  "de": "Erstes Wert:",           "ru": "Первое значение:"},
    "Second value":     {"en": "Second value:", "de": "Zweites Wert:",          "ru": "Второе значение:"},
    "Period":           {"en": "Period:",       "de": "Periode:",               "ru": "Повтор:"},
    "Color":            {"en": "Color:",        "de": "Farbe:",                 "ru": "Цвет:"},
    "once":             {"en": "once",          "de": "einmalig",               "ru": "один раз"},
    "daily":            {"en": "daily",         "de": "täglich",                "ru": "ежедневно"},
    "monthly":          {"en": "monthly",       "de": "monatlich",              "ru": "ежемесячно"},
    "Instruction":      {
        "en": "Drag and drop the events above to create a new one.<hr>Use ALT by dragging it to copy the events.",
        "de": "Schiebe die Ereignisse oben auf Kalendar um neue Ereignise zu erzeugen.<hr>Halte die ALT-Taste beim verschieben gedrückt um die Ereignisse zu kopieren.",
        "ru": "Что бы создать новые события, перетащите события сверху на календарь.<hr>Что бы скопировать событие удерживайте ALT при перетаскивании."
    },
    "Active":           {"en": "Active:",       "de": "Aktiviert:",             "ru": "Активно:"},
    "Time":             {"en": "Time:",         "de": "Zeit:",                  "ru": "Время:"},
    "Delete":           {"en": "Delete",        "de": "Löschen",                "ru": "Удалить"},
    "Cancel":           {"en": "Cancel",        "de": "Abbrechen",              "ru": "Отмена"},
    "Save":             {"en": "Save",          "de": "Speichern",              "ru": "Сохранить"},
    "Configure event":  {"en": "Configure event", "de": "Ereignis einstellen",  "ru": "Настроить событие"},
    "No action":        {"en": "No action",     "de": "Keine Aktion",           "ru": "Нет действия"},
    "Set value":        {"en": "Set value:",    "de": "Setze Wert:",            "ru": "Установить значение:"},
    "Set %s":           {"en": "Set %s",        "de": "Setze %s",               "ru": "Установить %s"},
    "Set %s to %s":     {"en": "Set %s to %s",  "de": "Setze %s zu %s",         "ru": "Установить %s в/на %s"},
    "Set to %s":        {"en": "Set to %s",     "de": "Setze zu %s",            "ru": "Установить в/на %s"},

    "sunrise":          {'en': 'sunrise',       "de": 'Sonnenaufgang',          'ru': 'восход солнца'},
    "sunriseEnd":       {'en': 'sunrise end',   "de": 'Sonnenaufgang-Ende',     'ru': 'конец восхода'},
    "goldenHourEnd":    {'en': 'golden hour end',"de": '"Golden hour"-Ende',    'ru': 'конец золотого часа'},
    "solarNoon":        {'en': 'solar noon',    "de": 'Sonnenmittag',           'ru': 'солнечеый полдень'},
    "goldenHour":       {'en': 'golden hour',   "de": '"Golden hour"',          'ru': 'золотой час'},
    "sunsetStart":      {'en': 'sunset start',  "de": 'Sonnenuntergang-Anfang', 'ru': 'начало захода солнца'},
    "sunset":           {'en': 'sunset',        "de": 'Sonnenuntergang',        'ru': 'конец захода солнца'},
    "dusk":             {'en': 'dusk',          "de": 'Abenddämmerung',         'ru': 'сумерки'},
    "nauticalDusk":     {'en': 'nautical dusk', "de": 'Nautische Abenddämmerung', 'ru': 'навигационные сумерки'},
    "night":            {'en': 'night',         "de": 'Nacht',                  'ru': 'ночь'},
    "nightEnd":         {'en': 'night end',     "de": 'Nachtsende',             'ru': 'конец ночи'},
    "nauticalDawn":     {'en': 'nautical dawn', "de": 'Nautische Morgendämmerung','ru': 'навигационный рассвет'},
    "dawn":             {'en': 'dawn',          "de": 'Morgendämmerung',        'ru': 'рассвет'},
    "nadir":            {'en': 'nadir',         "de": 'Nadir',                  'ru': 'надир'},

    "time":             {"en": "time",          "de": "Zeit",                   "ru": "время"},
    "astro":            {"en": "astro",         "de": "astro",                  "ru": "астро"},
    "Offset":           {"en": "Offset in minutes", "de": "Offset in Minuten",   "ru": "Сдвиг в минутах"},
    "scheduled":        {"en": "none",          "de": "nichts",                 "ru": "не показывать"},
    "configured":       {"en": "from Calendar", "de": "nur aus Kalender",             "ru": "только из календаря"},
    "all":              {"en": "all",           "de": "Alle",                   "ru": "все"},
    "Live Events":      {"en": "Live Events",   "de": "Zeige Ereignise",        "ru": "Показать события"},

    "Mo":               {"en": "Mo",            "de": "Mo",                     "ru": "Пн"},
    "Tu":               {"en": "Tu",            "de": "Di",                     "ru": "Вт"},
    "We":               {"en": "We",            "de": "Mi",                     "ru": "Ср"},
    "Th":               {"en": "Th",            "de": "Do",                     "ru": "Чт"},
    "Fr":               {"en": "Fr",            "de": "Fr",                     "ru": "Пт"},
    "Sa":               {"en": "Sa",            "de": "Sa",                     "ru": "Сб"},
    "Su":               {"en": "Su",            "de": "So",                     "ru": "Вс"},

    "Jan":              {"en": "Jan",           "de": "Jan",                    "ru": "Янв"},
    "Feb":              {"en": "Feb",           "de": "Feb",                    "ru": "Фев"},
    "Mar":              {"en": "Mar",           "de": "März",                   "ru": "Март"},
    "Apr":              {"en": "Apr",           "de": "Apr",                    "ru": "Апр"},
    "May":              {"en": "May",           "de": "Mai",                    "ru": "Май"},
    "Jun":              {"en": "Jun",           "de": "Jun",                    "ru": "Июнь"},
    "Jul":              {"en": "Jul",           "de": "Jul",                    "ru": "Июль"},
    "Aug":              {"en": "Aug",           "de": "Aug",                    "ru": "Авг"},
    "Sep":              {"en": "Sep",           "de": "Sept",                   "ru": "Сен"},
    "Oct":              {"en": "Oct",           "de": "Okt",                    "ru": "Окт"},
    "Nov":              {"en": "Nov",           "de": "Nov",                    "ru": "Ноя"},
    "Dec":              {"en": "Dec",           "de": "Dez",                    "ru": "Дек"},
    "notice_single":    {
        "en": "Will be triggered twice for one time event. One time by start and one time after defined duration. Please provide the <b>Object ID</b>, <b>start</b> and <b>end value</b>.",
        "de": "Wird zweimal für einmaliges Ereignis ausgelöst. Einmal beim Start und einmal nach dem definierten Intervall. Bitte geben Sie die <b> Objekt ID </b>, <b>Start-</b> und <b>Endwert</b> an.",
        "ru": "Будет срабатывать только один раз для временного события. Укажите <b>ID объекта</b> и <b>значение</b>, которое будет присвоено."
    },
    "notice_double":    {
        "en": "Will be triggered twice for one time event. One time by start and one time after defined duration. Please provide the <b>Object ID</b>, <b>start</b> and <b>end values</b>.",
        "de": "Wird zweimal für einmaliges Ereignis ausgelöst. Einmal beim Start und einmal nach dem definierte Intervall. Bitte geben Sie die <b>Objekt ID</b> und <b>Startwert</b> an. Der Endwert wird automatisch berechnet.",
        "ru": "Будет срабатывать дважды для одного временного события. Один раз в начале и один раз после установленного интервала. Укажите <b>ID объекта</b>, <b>начальное</b> и <b>конечные значения</b>."
    },
    "notice_toggle":    {
        "en": "Will be triggered twice for one time event. One time by start and one time after defined duration. Please provide the <b>Object ID</b> and <b>start value</b>. End value will be calculated automatically.",
        "de": "Wird zweimal für einmaliges Ereignis ausgelöst. Einmal beim Start und einmal nach definiertes Intervall. Bitte geben Sie die <b>Objekt ID</b> und <b>Startwert</b> an. Endwert wird automatisch berechnet.",
        "ru": "Будет срабатывать дважды для одного временного события. Один раз в начале и один раз после установленного интервала. Укажите <b>ID объекта</b> и <b>начальное значение</b>. Конечное значение будет рассчитываться автоматически."
    }
};
